@@ -28,6 +28,12 @@ from rich.prompt import Prompt
 
 
 class BaiduPCSApi:
+    """Baidu PCS Api
+
+    This is the wrapper of `BaiduPCS`. It parses the content of response of raw
+    BaiduPCS requests to some inner data structions.
+    """
+
     def __init__(
         self,
         bduss: Optional[str] = None,
@@ -73,20 +79,30 @@ class BaiduPCSApi:
         return self._baidupcs.cookies
 
     def quota(self) -> PcsQuota:
+        """Quota Information"""
+
         info = self._baidupcs.quota()
         return PcsQuota(quota=info["quota"], used=info["used"])
 
     def meta(self, *remotepaths: str) -> List[PcsFile]:
+        """Meta data of `remotepaths`"""
+
         info = self._baidupcs.meta(*remotepaths)
         return [PcsFile.from_(v) for v in info.get("list", [])]
 
     def exists(self, remotepath: str) -> bool:
+        """Check whether `remotepath` exists"""
+
         return self._baidupcs.exists(remotepath)
 
     def is_file(self, remotepath: str) -> bool:
+        """Check whether `remotepath` is a file"""
+
         return self._baidupcs.is_file(remotepath)
 
     def is_dir(self, remotepath: str) -> bool:
+        """Check whether `remotepath` is a directory"""
+
         return self._baidupcs.is_dir(remotepath)
 
     def list(
@@ -97,6 +113,8 @@ class BaiduPCSApi:
         time: bool = False,
         size: bool = False,
     ) -> List[PcsFile]:
+        """List directory contents"""
+
         info = self._baidupcs.list(
             remotepath, desc=desc, name=name, time=time, size=size
         )
@@ -109,6 +127,14 @@ class BaiduPCSApi:
         ondup="overwrite",
         callback: Callable[[MultipartEncoderMonitor], None] = None,
     ) -> PcsFile:
+        """Upload an io to `remotepath`
+
+        ondup (str): "overwrite" or "newcopy"
+        callable: the callback for monitoring uploading progress
+
+        Warning, the api CAN NOT set local_ctime and local_mtime
+        """
+
         info = self._baidupcs.upload_file(
             io, remotepath, ondup=ondup, callback=callback
         )
@@ -133,6 +159,9 @@ class BaiduPCSApi:
             if content_crc32 is 0, the params of the api will be ignored.
         io_len (int): the length of total content.
         remotepath (str): the absolute remote path to save the content.
+        local_ctime (optional, int): the timestramp of the local ctime
+        local_mtime (optional, int): the timestramp of the local mtime
+        ondup (str): "overwrite" or "newcopy"
         """
 
         info = self._baidupcs.rapid_upload_file(
@@ -150,6 +179,11 @@ class BaiduPCSApi:
     def upload_slice(
         self, io: IO, callback: Callable[[MultipartEncoderMonitor], None] = None
     ) -> str:
+        """Upload an io as a slice
+
+        callable: the callback for monitoring uploading progress
+        """
+
         info = self._baidupcs.upload_slice(io, callback=callback)
         return info["md5"]
 
@@ -161,6 +195,13 @@ class BaiduPCSApi:
         local_mtime: Optional[int] = None,
         ondup="overwrite",
     ) -> PcsFile:
+        """Combine uploaded slices to `remotepath`
+
+        local_ctime (optional, int): the timestramp of the local ctime
+        local_mtime (optional, int): the timestramp of the local mtime
+        ondup (str): "overwrite" or "newcopy"
+        """
+
         info = self._baidupcs.combine_slices(
             slice_md5s,
             remotepath,
@@ -173,6 +214,8 @@ class BaiduPCSApi:
     def search(
         self, keyword: str, remotepath: str, recursive: bool = False
     ) -> List[PcsFile]:
+        """Search in `remotepath` with `keyword`"""
+
         info = self._baidupcs.search(keyword, remotepath, recursive=recursive)
         pcs_files = []
         for file_info in info["list"]:
@@ -184,6 +227,8 @@ class BaiduPCSApi:
         return PcsFile.from_(info)
 
     def move(self, *remotepaths: str) -> List[FromTo]:
+        """Move `remotepaths[:-1]` to `remotepaths[-1]`"""
+
         info = self._baidupcs.move(*remotepaths)
         r = info["extra"].get("list")
         if not r:
@@ -199,6 +244,8 @@ class BaiduPCSApi:
         return FromTo(from_=v["from"], to_=v["to"])
 
     def copy(self, *remotepaths: str):
+        """Copy `remotepaths[:-1]` to `remotepaths[-1]`"""
+
         info = self._baidupcs.copy(*remotepaths)
         r = info["extra"].get("list")
         if not r:
@@ -206,26 +253,45 @@ class BaiduPCSApi:
         return [FromTo(from_=v["from"], to_=v["to"]) for v in r]
 
     def remove(self, *remotepaths: str):
+        """Remove all `remotepaths`"""
+
         self._baidupcs.remove(*remotepaths)
 
     def magnet_info(self, magnet: str) -> List[PcsMagnetFile]:
+        """Get the magnet information"""
+
         info = self._baidupcs.magnet_info(magnet)
         return [PcsMagnetFile.from_(v) for v in info["magnet_info"]]
 
     def torrent_info(self, remote_torrent: str):
+        """Get the `remote_torrent` information"""
+
         self._baidupcs.torrent_info(remote_torrent)
 
     def add_task(self, task_url: str, remotedir: str) -> str:
+        """Add a cloud task to save at `remotedir`
+
+        task_url (str): http url
+        """
+
         info = self._baidupcs.add_task(task_url, remotedir)
         return str(info["task_id"])
 
     def add_magnet_task(
         self, task_url: str, remotedir: str, selected_idx: List[int]
     ) -> str:
+        """Add a magnet task to save at `remotedir`.
+
+        task_url (str): magnet link
+        selected_idx: the indexes needed to download
+        """
+
         info = self._baidupcs.add_magnet_task(task_url, remotedir, selected_idx)
         return str(info["task_id"])
 
     def tasks(self, *task_ids: str) -> List[CloudTask]:
+        """List cloud tasks with their `task_ids`"""
+
         info = self._baidupcs.tasks(*task_ids)
         tasks = []
         for task_id, v in info["task_info"].items():
@@ -234,17 +300,28 @@ class BaiduPCSApi:
         return tasks
 
     def list_tasks(self) -> List[CloudTask]:
+        """List all cloud tasks"""
+
         info = self._baidupcs.list_tasks()
         return [CloudTask.from_(v) for v in info["task_info"]]
 
     def clear_tasks(self) -> int:
+        """Clear all finished and failed cloud tasks"""
+
         info = self._baidupcs.clear_tasks()
         return info["total"]
 
     def cancel_task(self, task_id: str):
+        """Cancel a cloud task with its `task_id`"""
+
         self._baidupcs.cancel_task(task_id)
 
     def share(self, *remotepaths: str, password: Optional[str] = None) -> PcsSharedLink:
+        """Share `remotepaths` to public with a optional password
+
+        To use api, `STOKEN` must be in `cookies`
+        """
+
         info = self._baidupcs.share(*remotepaths, password=password)
         link = PcsSharedLink.from_(info)._replace(
             paths=list(remotepaths), password=password
@@ -252,10 +329,20 @@ class BaiduPCSApi:
         return link
 
     def list_shared(self, page: int = 1) -> List[PcsSharedLink]:
+        """List shared link on a page
+
+        To use api, `STOKEN` must be in `cookies`
+        """
+
         info = self._baidupcs.list_shared(page)
         return [PcsSharedLink.from_(v) for v in info["list"]]
 
     def shared_password(self, share_id: int) -> Optional[str]:
+        """Show shared link password
+
+        To use api, `STOKEN` must be in `cookies`
+        """
+
         info = self._baidupcs.shared_password(share_id)
         p = info.get("pwd", "0")  # If "pwd" is not in info, error is 分享已过期
         if p == "0":
@@ -263,6 +350,11 @@ class BaiduPCSApi:
         return p
 
     def cancel_shared(self, *share_ids: int):
+        """Cancel shared links with their `share_ids`
+
+        To use api, `STOKEN` must be in `cookies`
+        """
+
         self._baidupcs.cancel_shared(*share_ids)
 
     def access_shared(
@@ -273,6 +365,14 @@ class BaiduPCSApi:
         vcode: str = "",
         show_vcode: bool = True,
     ):
+        """Verify the `shared_url` which needs the `password`
+
+        This method MUST be called before calling `self.shared_paths`.
+
+        show_vcode (bool): If set True, it will be open the vcode image (if needed)
+            with a gui window. Else, you need to handle the vcode.
+        """
+
         while True:
             try:
                 self._baidupcs.access_shared(shared_url, password, vcode_str, vcode)
@@ -296,15 +396,21 @@ class BaiduPCSApi:
                     raise err
 
     def getcaptcha(self, shared_url: str) -> Tuple[str, str]:
-        """Return `vcode_str`, `vcode_img_url`"""
+        """Get one vcode information
+
+        Return `vcode_str`, `vcode_img_url`"""
 
         info = self._baidupcs.getcaptcha(shared_url)
         return info["vcode_str"], info["vcode_img"]
 
     def get_vcode_img(self, vcode_img_url: str, shared_url: str) -> bytes:
+        """Get vcode image content"""
+
         return self._baidupcs.get_vcode_img(vcode_img_url, shared_url)
 
     def shared_paths(self, shared_url: str) -> List[PcsSharedPath]:
+        """Shared paths of the `shared_url`"""
+
         info = self._baidupcs.shared_paths(shared_url)
         uk = info.get("share_uk") or info.get("uk")
         uk = int(uk)
@@ -338,6 +444,8 @@ class BaiduPCSApi:
         page: int = 1,
         size: int = 100,
     ) -> List[PcsSharedPath]:
+        """Sub shared paths of the shared directory `sharedpath`"""
+
         info = self._baidupcs.list_shared_paths(
             sharedpath, uk, share_id, page=page, size=size
         )
@@ -355,11 +463,15 @@ class BaiduPCSApi:
         bdstoken: str,
         shared_url: str,
     ):
+        """Save these `fs_ids` of shared paths to `remotedir`"""
+
         self._baidupcs.transfer_shared_paths(
             remotedir, fs_ids, uk, share_id, bdstoken, shared_url
         )
 
     def user_info(self) -> PcsUser:
+        """User's information"""
+
         info = self._baidupcs.user_info()
         user_id = int(info["user"]["id"])
         user_name = info["user"]["name"]
@@ -397,6 +509,8 @@ class BaiduPCSApi:
         )
 
     def user_products(self) -> Tuple[List[PcsUserProduct], int]:
+        """User's product information"""
+
         info = self._baidupcs.user_products()
         pds = []
         for p in info["product_infos"]:
@@ -416,6 +530,14 @@ class BaiduPCSApi:
         return pds, level
 
     def download_link(self, remotepath: str, pcs: bool = False) -> Optional[str]:
+        """Download link of the `remotepath`
+
+        pcs (bool, default: False): If pcs is True, return the downloading pcs link
+            which has a limited threshold of downstream even if the user is a svip.
+            If pcs is False, return the downloading link requested by the android api
+            and which has not limited threshold for a svip user.
+        """
+
         return self._baidupcs.download_link(remotepath, pcs=pcs)
 
     def file_stream(
@@ -426,6 +548,8 @@ class BaiduPCSApi:
         encrypt_password: bytes = b"",
         pcs: bool = False,
     ) -> Optional[RangeRequestIO]:
+        """File stream as a normal io"""
+
         return self._baidupcs.file_stream(
             remotepath,
             max_chunk_size=max_chunk_size,
@@ -435,6 +559,8 @@ class BaiduPCSApi:
         )
 
     def m3u8_stream(self, remotepath: str, type: M3u8Type = "M3U8_AUTO_720") -> str:
+        """Media file's m3u8 content"""
+
         info = self._baidupcs.m3u8_stream(remotepath, type)
         if info.get("m3u8_content"):
             return info["m3u8_content"]
@@ -445,6 +571,13 @@ class BaiduPCSApi:
     def rapid_upload_info(
         self, remotepath: str, check: bool = True
     ) -> Optional[PcsRapidUploadInfo]:
+        """Rapid upload information
+
+        check (bool): If check is True, we need to use the `self.rapid_upload_file` to
+            check whether the rapid upload information is valid. Therefore some meta information
+            of the `remotepath` will be changed. These are server_ctime and server_mtime.
+        """
+
         pcs_file = self.meta(remotepath)[0]
         content_length = pcs_file.size
 
